"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var view_1 = require("tns-core-modules/ui/core/view/view");
var profiling_1 = require("tns-core-modules/profiling");
var content_view_1 = require("tns-core-modules/ui/content-view/content-view");
var scrollBarIndicatorVisibleProperty = new view_1.Property({
    name: 'scrollBarIndicatorVisible',
    defaultValue: true,
    valueConverter: view_1.booleanConverter
});
var converter = view_1.makeParser(view_1.makeValidator('horizontal', 'vertical'));
exports.orientationProperty = new view_1.Property({
    name: 'orientation',
    defaultValue: 'vertical',
    affectsLayout: true,
    valueChanged: function (target, oldValue, newValue) {
        target._onOrientationChanged();
    },
    valueConverter: converter
});
var NestedScrollViewNamespace = useAndroidX() ? global.androidx.core.widget : android.support.v4.widget;
function useAndroidX() {
    return global.androidx && global.androidx.core.widget;
}
var NestedScrollView = (function (_super) {
    __extends(NestedScrollView, _super);
    function NestedScrollView() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._androidViewId = -1;
        return _this;
    }
    NestedScrollView.prototype.createNativeView = function () {
        return new NestedScrollViewNamespace.NestedScrollView(this._context);
    };
    NestedScrollView.prototype.initNativeView = function () {
        if (this._androidViewId < 0) {
            this._androidViewId = android.view.View.generateViewId();
        }
        this.nativeViewProtected.setId(this._androidViewId);
    };
    NestedScrollView.prototype.onLoaded = function () {
        _super.prototype.onLoaded.call(this);
        var that = new WeakRef(this);
        this.handler = new NestedScrollViewNamespace.NestedScrollView.OnScrollChangeListener({
            onScrollChange: function (view, scrollX, scrollY, oldScrollX, oldScrollY) {
                var owner = that.get();
                if (owner) {
                    owner.notify({
                        object: this,
                        eventName: NestedScrollView.scrollEvent,
                        scrollX: scrollX,
                        scrollY: scrollY
                    });
                }
            }
        });
        this.nativeView.setOnScrollChangeListener(this.handler);
    };
    NestedScrollView.prototype.onUnloaded = function () {
        _super.prototype.onUnloaded.call(this);
        this.nativeView.setOnScrollChangeListener(this.handler);
        this.handler = null;
    };
    NestedScrollView.prototype._onOrientationChanged = function () {
        if (this.nativeViewProtected) {
            var parent_1 = this.parent;
            if (parent_1) {
                parent_1._removeView(this);
                parent_1._addView(this);
            }
        }
    };
    NestedScrollView.prototype[scrollBarIndicatorVisibleProperty.getDefault] = function () {
        return true;
    };
    NestedScrollView.prototype[scrollBarIndicatorVisibleProperty.setNative] = function (value) {
        if (this.orientation === 'horizontal') {
            this.nativeViewProtected.setHorizontalScrollBarEnabled(value);
        }
        else {
            this.nativeViewProtected.setVerticalScrollBarEnabled(value);
        }
    };
    NestedScrollView.prototype.scrollToVerticalOffset = function (value, animated) {
        var nativeView = this.nativeViewProtected;
        if (nativeView && this.orientation === 'vertical') {
            value *= view_1.layout.getDisplayDensity();
            if (animated) {
                nativeView.smoothScrollTo(0, value);
            }
            else {
                nativeView.scrollTo(0, value);
            }
        }
    };
    NestedScrollView.prototype.scrollToHorizontalOffset = function (value, animated) {
        var nativeView = this.nativeViewProtected;
        if (nativeView && this.orientation === 'horizontal') {
            value *= view_1.layout.getDisplayDensity();
            if (animated) {
                nativeView.smoothScrollTo(value, 0);
            }
            else {
                nativeView.scrollTo(value, 0);
            }
        }
    };
    Object.defineProperty(NestedScrollView.prototype, "horizontalOffset", {
        get: function () {
            var nativeView = this.nativeViewProtected;
            if (!nativeView) {
                return 0;
            }
            return nativeView.getScrollX() / view_1.layout.getDisplayDensity();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NestedScrollView.prototype, "verticalOffset", {
        get: function () {
            var nativeView = this.nativeViewProtected;
            if (!nativeView) {
                return 0;
            }
            return nativeView.getScrollY() / view_1.layout.getDisplayDensity();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NestedScrollView.prototype, "scrollableWidth", {
        get: function () {
            var nativeView = this.nativeViewProtected;
            if (!nativeView || this.orientation !== 'horizontal') {
                return 0;
            }
            return this.getScrollableLength() / view_1.layout.getDisplayDensity();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NestedScrollView.prototype, "scrollableHeight", {
        get: function () {
            var nativeView = this.nativeViewProtected;
            if (!nativeView || this.orientation !== 'vertical') {
                return 0;
            }
            return this.getScrollableLength() / view_1.layout.getDisplayDensity();
        },
        enumerable: true,
        configurable: true
    });
    NestedScrollView.prototype.getScrollableLength = function () {
        if (!this.nativeView) {
            return 0;
        }
        return this.nativeView.getChildAt(0).getHeight();
    };
    NestedScrollView.scrollEvent = 'scroll';
    __decorate([
        profiling_1.profile,
        __metadata("design:type", Function),
        __metadata("design:paramtypes", []),
        __metadata("design:returntype", void 0)
    ], NestedScrollView.prototype, "onLoaded", null);
    return NestedScrollView;
}(content_view_1.ContentView));
exports.NestedScrollView = NestedScrollView;
scrollBarIndicatorVisibleProperty.register(NestedScrollView);
exports.orientationProperty.register(NestedScrollView);
//# sourceMappingURL=nested-scrollview.android.js.map